49 void *
vx,
void *
vy,
void *
vz,
50 void *
dx,
void *
dy,
void *
dz,
62 void *
vx,
void *
vy,
void *
vz,
63 void *
dx,
void *
dy,
void *
dz,
67 void *
jacinv,
int *nel,
int *gdim,
int *lx) {
80#define CASE_1D(LX, C) \
81 conv1_kernel_1d<real, LX, NEKO_CHUNKS(LX, C)> \
82 <<<nblcks, NEKO_CHUNKS_NTHRDS(LX, C), 0, stream>>> \
83 ((real *) du, (real *) u, \
84 (real *) vx, (real *) vy, (real *) vz, \
85 (real *) dx, (real *) dy, (real *) dz, \
86 (real *) drdx, (real *) dsdx, (real *) dtdx, \
87 (real *) drdy, (real *) dsdy, (real *) dtdy, \
88 (real *) drdz, (real *) dsdz, (real *) dtdz, \
90 CUDA_CHECK(cudaGetLastError());
93#define CASE_1D_SEL(LX, SEL) \
95 case 0: CASE_1D(LX, 0); break; \
96 case 1: CASE_1D(LX, 1); break; \
97 case 2: CASE_1D(LX, 2); break; \
98 default: CASE_1D(LX, 3); break; \
101#define CASE_KSTEP(LX, C) \
102 conv1_kernel_kstep<real, LX, NEKO_EB(LX, C)> \
103 <<<NEKO_EB_NBLCKS(*nel, LX, C), NEKO_EB_NTHRDS(LX, C), 0, stream>>> \
104 ((real *) du, (real *) u, \
105 (real *) vx, (real *) vy, (real *) vz, \
106 (real *) dx, (real *) dy, (real *) dz, \
107 (real *) drdx, (real *) dsdx, (real *) dtdx, \
108 (real *) drdy, (real *) dsdy, (real *) dtdy, \
109 (real *) drdz, (real *) dsdz, (real *) dtdz, \
110 (real *) jacinv, *nel); \
111 CUDA_CHECK(cudaGetLastError());
114#define CASE_KSTEP_SEL(LX, SEL) \
116 case 0: CASE_KSTEP(LX, 0); break; \
117 case 1: CASE_KSTEP(LX, 1); break; \
118 default: CASE_KSTEP(LX, 2); break; \
123 if(autotune[LX] == 0 ) { \
124 autotune[LX]=tune_conv1<LX>(du, u, \
130 jacinv, nel, gdim, lx, &autotune_eb[LX], \
132 } else if (autotune[LX] == 1 ) { \
133 CASE_1D_SEL(LX, autotune_ch[LX]); \
134 } else if (autotune[LX] == 2 ) { \
135 CASE_KSTEP_SEL(LX, autotune_eb[LX]); \
139#define CASE_LARGE(LX) \
181template < const
int LX >
183 void *
vx,
void *
vy,
void *
vz,
184 void *
dx,
void *
dy,
void *
dz,
264 for (
int r = 0; r <
rounds; r++) {
__global__ void ale_add_kinematics_kernel(const int n, T *__restrict__ wx, T *__restrict__ wy, T *__restrict__ wz, const T *__restrict__ x_ref, const T *__restrict__ y_ref, const T *__restrict__ z_ref, const T *__restrict__ phi, const T *__restrict__ x, const T *__restrict__ y, const T *__restrict__ z, const kinematics_params_t kin_params)
__global__ void T *__restrict__ T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ drdy
__global__ void T *__restrict__ T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ drdz
__global__ void T *__restrict__ T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ dsdz
__global__ void T *__restrict__ T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ dsdy
__global__ void T *__restrict__ T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ dtdy
__global__ void T *__restrict__ T *__restrict__ const T *__restrict__ u
__global__ void T *__restrict__ T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ dx
__global__ void T *__restrict__ T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ drdx
__global__ void T *__restrict__ T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ dtdz
__global__ void T *__restrict__ T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ dsdx
__global__ void T *__restrict__ T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ dtdx
__global__ void T *__restrict__ T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ dz
__global__ void T *__restrict__ T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ dy
__global__ void T *__restrict__ T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ jacinv
__global__ void const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ vz
__global__ void const T *__restrict__ const T *__restrict__ vx
__global__ void const T *__restrict__ const T *__restrict__ const T *__restrict__ vy
#define NEKO_CHUNKS_CANDIDATES
#define NEKO_EB_CANDIDATES
#define NEKO_EB_SEL(LX, SEL)
#define NEKO_CHUNKS_SEL(LX, SEL)
#define NEKO_TUNE_TIME(T, LAUNCH, LX, C, ITERS)
static int neko_tune_rounds()
#define NEKO_TUNE_LOG(LX, T1, T2)
#define NEKO_TUNE_BEST(T, BEST, N)
static int neko_tune_iters()
static int neko_chunks_env()
static int neko_eb_sweep()
void log_error(char *msg)
void log_message(char *msg)
void log_section(char *msg)
int tune_conv1(void *du, void *u, void *vx, void *vy, void *vz, void *dx, void *dy, void *dz, void *drdx, void *dsdx, void *dtdx, void *drdy, void *dsdy, void *dtdy, void *drdz, void *dsdz, void *dtdz, void *jacinv, int *nel, int *gdim, int *lx, int *eb_sel, int *ch_sel)
#define CASE_KSTEP_SEL(LX, SEL)
void cuda_conv1(void *du, void *u, void *vx, void *vy, void *vz, void *dx, void *dy, void *dz, void *drdx, void *dsdx, void *dtdx, void *drdy, void *dsdy, void *dtdy, void *drdz, void *dsdz, void *dtdz, void *jacinv, int *nel, int *gdim, int *lx)
#define CASE_1D_SEL(LX, SEL)
#define CASE_KSTEP(LX, C)